@@ -1,12 +1,12 @@
 import json
 import logging
 import os
-from typing import Callable, Dict, List
+from typing import Callable, Dict, List, Optional
 
 import pandas
 from fastapi.encoders import jsonable_encoder
 
-from .accuracy import calibration, largest_errors, metrics
+from .accuracy import calibration, largest_errors, metrics, roc_curve
 from .dependence import partialdep
 from .expectations import condexp
 from .importance import varimp
@@ -105,6 +105,13 @@ def create_accuracy(
     with open(fpath, "w") as f:
         f.write(errors_table)
 
+    if kind == "binary":
+        logging.info("Accuracy - Creating ROC curve")
+        fname = "roc_curve.json"
+        fpath = os.path.join(folder, fname)
+        chart = roc_curve(func, x, y)
+        chart.save(fpath, format="json")
+
 
 def create_dependence(
     func: Callable, x: pandas.DataFrame, endpoint_name: str, profile_columns: List[str],
@@ -180,7 +187,11 @@ def create_importance(
 
 
 def create_summary(
-    endpoint_name: str, input_names: List[str], output_names: str, kind: str
+    endpoint_name: str,
+    input_names: List[str],
+    output_names: str,
+    kind: str,
+    version: Optional[str] = None,
 ) -> None:
 
     logging.info(f"Summary - creating endpoint summary for endpoint: {endpoint_name}")
@@ -190,6 +201,8 @@ def create_summary(
         "inputs": input_names,
         "output": output_names,
     }
+    if version:
+        as_json["version"] = version
     # Save to disk
     folder = mkdir(endpoint_name=endpoint_name)
     with open(os.path.join(folder, "summary.json"), "w") as summary:
